from pymcutil.util.symbol import Symbol


class SelectorSort(Symbol):
    pass


nearest = SelectorSort('nearest')
furthest = SelectorSort('furthest')
random = SelectorSort('random')
arbitrary = SelectorSort('arbitrary')
