from .player_selector import player, PLAYER
from .random_selector import random, RANDOM
from .all_players_selector import all_players, ALL_PLAYERS
from .entities_selector import entities, ENTITIES
from .self_selector import self, SELF
