DATA_DIRECTORY = 'data'

ADVANCEMENTS_DIRECTORY = 'advancements'
FUNCTIONS_DIRECTORY = 'functions'
LOOT_TABLES_DIRECTORY = 'loot_tables'

ADVANCEMENTS_EXTENSION = 'json'
FUNCTIONS_EXTENSION = 'mcfunction'
LOOT_TABLES_EXTENSION = 'json'
