from pymcutil.util.symbol import Symbol


class Gamemode(Symbol):
    pass


survival = Gamemode('survival')
adventure = Gamemode('adventure')
creative = Gamemode('creative')
spectator = Gamemode('spectator')
